# FiftyOne Brain -- Experiment:  Label Error

How can we demonstrate that fiftyone can be used to detect annotation mistakes (or rank the potential that specific labels are wrong).

Problem: Classification

This code does not explicitly use eta or theta because it is intended as something that could be shared for a simple use of fiftyone without learning anything else about Voxel51





## Copyright

Copyright 2017-2023, Voxel51, Inc.<br>
voxel51.com
